compute_inclusive_end

Function compute_inclusive_end 

fn compute_inclusive_end(start: u32, len: u32) -> Option<u32>
Helper to compute the inclusive end of a range given a start and length, returning None if len == 0 or the computation would overflow.